# swagger-client
Brawl Stars API

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v1
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: JWT
configuration = swagger_client.Configuration()
configuration.api_key['authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['authorization'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.BrawlersApi(swagger_client.ApiClient(configuration))
brawler_id = 'brawler_id_example' # str | Identifier of the brawler.

try:
    # Get information about a brawler.
    api_response = api_instance.get_brawler(brawler_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling BrawlersApi->get_brawler: %s\n" % e)

# Configure API key authorization: JWT
configuration = swagger_client.Configuration()
configuration.api_key['authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['authorization'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.BrawlersApi(swagger_client.ApiClient(configuration))
before = 'before_example' # str | Return only items that occur before this marker. Before marker can be found from the response, inside the 'paging' property. Note that only after or before can be specified for a request, not both.  (optional)
after = 'after_example' # str | Return only items that occur after this marker. Before marker can be found from the response, inside the 'paging' property. Note that only after or before can be specified for a request, not both.  (optional)
limit = 56 # int | Limit the number of items returned in the response. (optional)

try:
    # Get list of available brawlers.
    api_response = api_instance.get_brawlers(before=before, after=after, limit=limit)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling BrawlersApi->get_brawlers: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.brawlstars.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BrawlersApi* | [**get_brawler**](docs/BrawlersApi.md#get_brawler) | **GET** /brawlers/{brawlerId} | Get information about a brawler.
*BrawlersApi* | [**get_brawlers**](docs/BrawlersApi.md#get_brawlers) | **GET** /brawlers | Get list of available brawlers.
*ClubsApi* | [**get_club**](docs/ClubsApi.md#get_club) | **GET** /clubs/{clubTag} | Get club information.
*ClubsApi* | [**get_club_members**](docs/ClubsApi.md#get_club_members) | **GET** /clubs/{clubTag}/members | List club members.
*PlayersApi* | [**get_battle_log**](docs/PlayersApi.md#get_battle_log) | **GET** /players/{playerTag}/battlelog | Get log of recent battles for a player.
*PlayersApi* | [**get_player**](docs/PlayersApi.md#get_player) | **GET** /players/{playerTag} | Get player information
*RankingsApi* | [**get_brawler_rankings**](docs/RankingsApi.md#get_brawler_rankings) | **GET** /rankings/{countryCode}/brawlers/{brawlerId} | Get brawler rankings for a country or global rankings.
*RankingsApi* | [**get_club_rankings**](docs/RankingsApi.md#get_club_rankings) | **GET** /rankings/{countryCode}/clubs | Get club rankings for a country or global rankings.
*RankingsApi* | [**get_player_rankings**](docs/RankingsApi.md#get_player_rankings) | **GET** /rankings/{countryCode}/players | Get player rankings for a country or global rankings.

## Documentation For Models

 - [Battle](docs/Battle.md)
 - [BattleList](docs/BattleList.md)
 - [BattleResult](docs/BattleResult.md)
 - [Brawler](docs/Brawler.md)
 - [BrawlerList](docs/BrawlerList.md)
 - [BrawlerStat](docs/BrawlerStat.md)
 - [BrawlerStatList](docs/BrawlerStatList.md)
 - [ClientError](docs/ClientError.md)
 - [Club](docs/Club.md)
 - [ClubMember](docs/ClubMember.md)
 - [ClubMemberList](docs/ClubMemberList.md)
 - [ClubRanking](docs/ClubRanking.md)
 - [ClubRankingList](docs/ClubRankingList.md)
 - [Event](docs/Event.md)
 - [JsonLocalizedName](docs/JsonLocalizedName.md)
 - [Player](docs/Player.md)
 - [PlayerClub](docs/PlayerClub.md)
 - [PlayerRanking](docs/PlayerRanking.md)
 - [PlayerRankingClub](docs/PlayerRankingClub.md)
 - [PlayerRankingList](docs/PlayerRankingList.md)
 - [StarPower](docs/StarPower.md)
 - [StarPowerList](docs/StarPowerList.md)

## Documentation For Authorization


## JWT

- **Type**: API key
- **API key parameter name**: authorization
- **Location**: HTTP header


## Author


